<?php
namespace Teknisa\DF\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\Libs\Util\Environment;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\DF\Factories\Ger57000TabelaDoSimplesNacionalFactory;

class Ger57000TabelaDoSimplesNacionalService extends \Teknisa\DF\Controllers\TeknisaCrud {
    
    const msgErros = array(
        "DtInt_CFOP_Inv"    => "CFOP já relacionado para o intervalo de validade.",
        "DtFim_CFOP_Inf"    => "Data de validade final da tabela deve ser informada. CFOP já relacionado para outro intervalo em período posterior.",
        "DtFimOld_CFOP_Inf" => "CFOP já relacionado para intervalo inferior sem data final informada.",
        
        "DtInt_OPER_Inv"    => "Tipo de Operação já relacionado para o intervalo de validade.",
        "DtFim_OPER_Inf"    => "Data de validade final da tabela deve ser informada. Tipo de Operação já relacionado para outro intervalo em período posterior.",
        "DtFimOld_OPER_Inf" => "Tipo de Operação já relacionado para intervalo inferior sem data final informada."
    );
    
    protected $environment;
    protected $dataSourceManager;
    protected $factory;
    protected $crudService;
    protected $newCode;
    protected $nrorg;
    protected $operador;
    protected $currentTime;

    public function __construct(Environment $environment, $dataSourceManager, $factory, $crudService){
        $this->environment       = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->factory           = $factory;
        $this->crudService       = $crudService;
        $this->nrorg             = $environment->getNrorgTrab();
        $this->operador          = $this->environment->getCdOperador();
        $this->currentTime       = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
    }
    
     
    public function getPrxFaixa($params) {
       
        $cdfaixa = $this->factory->getPrxFaixa($params);

        return $cdfaixa[0]['PRX_FAIXA'];

    }
    
    public function deleteTabelaDeReferencia($tabela) {
        
        $this->factory->deleteTipoOperacSimples($tabela);
        $this->factory->deleteCfopSimples($tabela);
        $this->factory->deleteAllImpostosFaixa($tabela);
        $this->factory->deleteAllFaixa($tabela);
        $this->factory->deleteTabelaDeReferencia($tabela);
        
    }
    
    public function saveFaixa($requestSalvar) {
        
        $saveRows = $this->crudService->getRowsToSave($requestSalvar, 'faixasimplesnac');
        return $this->crudService->save('faixasimplesnac', $saveRows);
    }
    
    public function saveImpFaixa($requestSalvar) {
        $saveRows = $this->crudService->getRowsToSave($requestSalvar, 'impsimplesfaixa');
        return $this->crudService->save('impsimplesfaixa', $saveRows);
    }
    
    public function deleteImpostosFaixa($row) {
        $this->factory->deleteImpostosFaixa($row['CDFAIXA'],$row['CDSIMPLESNACIONAL']);
    }
    
    public function deleteFaixa($row) {
        $this->factory->deleteImpostosFaixa($row['CDFAIXA'],$row['CDSIMPLESNACIONAL']);
        $this->factory->deleteFaixa($row['CDFAIXA'],$row['CDSIMPLESNACIONAL']);
    } 

    public function validaIntervaloCfop($row){
        $tabelaSimples = $this->factory->getTabelasSimplesNacioanl($row['CDSIMPLESNACIONAL']);
        $resul         = $this->factory->validaIntervaloCfop($tabelaSimples['DTINIVIGENCIA'], $tabelaSimples['DTFIMVIGENCIA'], $tabelaSimples['CDSIMPLESNACIONAL'], $row['CDCFOPPADRAO']);
        if($resul){
            if($resul['DSCFOPPADRAO'])
                throw new \Exception(self::msgErros[$resul['DSCFOPPADRAO']]);
        }
    }
    
    public function validaIntervaloTipoOperacao($row){
        $tabelaSimples = $this->factory->getTabelasSimplesNacioanl($row['CDSIMPLESNACIONAL']);
        $resul         = $this->factory->validaIntervaloTipoOperacao($tabelaSimples['DTINIVIGENCIA'], $tabelaSimples['DTFIMVIGENCIA'], $tabelaSimples['CDSIMPLESNACIONAL'], $row['CDTIPOOPER']);
        if($resul){
            if($resul['NMTIPOOPER'])
                throw new \Exception(self::msgErros[$resul['NMTIPOOPER']]);
        }
    }
    
    public function validaEdicaoTabelaSimplesNacional($row){
        $resul  = $this->factory->validaEdicaoTabelaSimplesNacional($row['DTINIVIGENCIA'], $row['DTFIMVIGENCIA'], $row['CDSIMPLESNACIONAL']);
        if($resul){
            if($resul['DSERRO'])
                throw new \Exception(self::msgErros[$resul['DSERRO']]);
        }
    }

}